==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/currencies/en_AU.php <==
<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'United Arab Emirates Dirham',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghan Afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanian Lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armenian Dram',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolan Kwanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentine Peso',
        ],
        'AUD' => [
            0 => '$',
            1 => 'Australian Dollar',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaijani Manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnia-Herzegovina Convertible Marka',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados Dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeshi Taka',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgarian Lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahraini Dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundian Franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda Dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunei Dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Boliviano',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Brazilian Real',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutanese Ngultrum',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswanan Pula',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Canadian Dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Congolese Franc',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Swiss Franc',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chilean Peso',
        ],
        'CNH' => [
            0 => 'CNH',
            1 => 'CNH',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Chinese Yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Colombian Peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Cape Verdean Escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Czech Koruna',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboutian Franc',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algerian Dinar',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptian Pound',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrean Nakfa',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ethiopian Birr',
        ],
        'EUR' => [
            0 => 'EUR',
            1 => 'Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fijian Dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falkland Islands Pound',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'British Pound',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgian Lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanaian Cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar Pound',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambian Dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinean Franc',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyanaese Dollar',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Hong Kong Dollar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Croatian Kuna',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Hungarian Forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesian Rupiah',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Israeli Shekel',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Indian Rupee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Iraqi Dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranian Rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Icelandic Króna',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordanian Dinar',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'Japanese Yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenyan Shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kyrgystani Som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Cambodian Riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Comorian Franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'North Korean Won',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'South Korean Won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuwaiti Dinar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazakhstani Tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laotian Kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Lebanese Pound',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankan Rupee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberian Dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotho Loti',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libyan Dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Moroccan Dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovan Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagasy Ariary',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedonian Denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmar Kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolian Tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macanese Pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritanian Ouguiya (1973–2017)',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritian Rupee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivian Rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawian Kwacha',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Mexican Peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaysian Ringgit',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambican Metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibian Dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerian Naira',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norwegian Krone',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalese Rupee',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'New Zealand Dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omani Rial',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruvian Sol',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua New Guinean Kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Philippine Peso',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polish Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayan Guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatari Riyal',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Romanian Leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbian Dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russian Rouble',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Rwandan Franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudi Riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon Islands Dollar',
        ],
        'SCR' => [
            0 => 'Rs',
            1 => 'Seychellois Rupee',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanese Pound',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Swedish Krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapore Dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'St Helena Pound',
        ],
        'SLL' => [
            0 => 'SLL',
            1 => 'Sierra Leonean Leone',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali Shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Suriname Dollar',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'South Sudanese Pound',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syrian Pound',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazi Lilangeni',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tajikistani Somoni',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistani Manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisian Dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongan Paʻanga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkish Lira',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'New Taiwan Dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzanian Shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrainian Hryvnia',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandan Shilling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'US Dollar',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso Uruguayo',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistani Som',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezuelan Bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'VES',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Vietnamese Dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu Vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoan Tala',
        ],
        'XAF' => [
            0 => 'XAF',
            1 => 'Central African CFA Franc',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'East Caribbean Dollar',
        ],
        'XOF' => [
            0 => 'XOF',
            1 => 'West African CFA Franc',
        ],
        'XPF' => [
            0 => 'CFP',
            1 => 'CFP Franc',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Yemeni Rial',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'South African Rand',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambian Kwacha',
        ],
    ],
];

==> symfony_5.4.16+dfsg.orig.tar.xz: symfony-5.4.16/src/Symfony/Component/Intl/Resources/data/currencies/en_AU.php <==
<?php

return [
    'Names' => [
        'AED' => [
            0 => 'AED',
            1 => 'United Arab Emirates Dirham',
        ],
        'AFN' => [
            0 => 'AFN',
            1 => 'Afghan Afghani',
        ],
        'ALL' => [
            0 => 'ALL',
            1 => 'Albanian Lek',
        ],
        'AMD' => [
            0 => 'AMD',
            1 => 'Armenian Dram',
        ],
        'AOA' => [
            0 => 'AOA',
            1 => 'Angolan Kwanza',
        ],
        'ARS' => [
            0 => 'ARS',
            1 => 'Argentine Peso',
        ],
        'AUD' => [
            0 => '$',
            1 => 'Australian Dollar',
        ],
        'AZN' => [
            0 => 'AZN',
            1 => 'Azerbaijani Manat',
        ],
        'BAM' => [
            0 => 'BAM',
            1 => 'Bosnia-Herzegovina Convertible Marka',
        ],
        'BBD' => [
            0 => 'BBD',
            1 => 'Barbados Dollar',
        ],
        'BDT' => [
            0 => 'BDT',
            1 => 'Bangladeshi Taka',
        ],
        'BGN' => [
            0 => 'BGN',
            1 => 'Bulgarian Lev',
        ],
        'BHD' => [
            0 => 'BHD',
            1 => 'Bahraini Dinar',
        ],
        'BIF' => [
            0 => 'BIF',
            1 => 'Burundian Franc',
        ],
        'BMD' => [
            0 => 'BMD',
            1 => 'Bermuda Dollar',
        ],
        'BND' => [
            0 => 'BND',
            1 => 'Brunei Dollar',
        ],
        'BOB' => [
            0 => 'BOB',
            1 => 'Bolivian boliviano',
        ],
        'BRL' => [
            0 => 'BRL',
            1 => 'Brazilian Real',
        ],
        'BTN' => [
            0 => 'BTN',
            1 => 'Bhutanese Ngultrum',
        ],
        'BWP' => [
            0 => 'BWP',
            1 => 'Botswanan Pula',
        ],
        'CAD' => [
            0 => 'CAD',
            1 => 'Canadian Dollar',
        ],
        'CDF' => [
            0 => 'CDF',
            1 => 'Congolese Franc',
        ],
        'CHF' => [
            0 => 'CHF',
            1 => 'Swiss Franc',
        ],
        'CLP' => [
            0 => 'CLP',
            1 => 'Chilean Peso',
        ],
        'CNY' => [
            0 => 'CNY',
            1 => 'Chinese Yuan',
        ],
        'COP' => [
            0 => 'COP',
            1 => 'Colombian Peso',
        ],
        'CUP' => [
            0 => 'CUP',
            1 => 'Cuban Peso',
        ],
        'CVE' => [
            0 => 'CVE',
            1 => 'Cape Verdean Escudo',
        ],
        'CZK' => [
            0 => 'CZK',
            1 => 'Czech Koruna',
        ],
        'DJF' => [
            0 => 'DJF',
            1 => 'Djiboutian Franc',
        ],
        'DZD' => [
            0 => 'DZD',
            1 => 'Algerian Dinar',
        ],
        'EGP' => [
            0 => 'EGP',
            1 => 'Egyptian Pound',
        ],
        'ERN' => [
            0 => 'ERN',
            1 => 'Eritrean Nakfa',
        ],
        'ETB' => [
            0 => 'ETB',
            1 => 'Ethiopian Birr',
        ],
        'EUR' => [
            0 => 'EUR',
            1 => 'Euro',
        ],
        'FJD' => [
            0 => 'FJD',
            1 => 'Fijian Dollar',
        ],
        'FKP' => [
            0 => 'FKP',
            1 => 'Falkland Islands Pound',
        ],
        'GBP' => [
            0 => 'GBP',
            1 => 'British Pound',
        ],
        'GEL' => [
            0 => 'GEL',
            1 => 'Georgian Lari',
        ],
        'GHS' => [
            0 => 'GHS',
            1 => 'Ghanaian Cedi',
        ],
        'GIP' => [
            0 => 'GIP',
            1 => 'Gibraltar Pound',
        ],
        'GMD' => [
            0 => 'GMD',
            1 => 'Gambian Dalasi',
        ],
        'GNF' => [
            0 => 'GNF',
            1 => 'Guinean Franc',
        ],
        'GYD' => [
            0 => 'GYD',
            1 => 'Guyanaese Dollar',
        ],
        'HKD' => [
            0 => 'HKD',
            1 => 'Hong Kong Dollar',
        ],
        'HRK' => [
            0 => 'HRK',
            1 => 'Croatian Kuna',
        ],
        'HUF' => [
            0 => 'HUF',
            1 => 'Hungarian Forint',
        ],
        'IDR' => [
            0 => 'IDR',
            1 => 'Indonesian Rupiah',
        ],
        'ILS' => [
            0 => 'ILS',
            1 => 'Israeli Shekel',
        ],
        'INR' => [
            0 => 'INR',
            1 => 'Indian Rupee',
        ],
        'IQD' => [
            0 => 'IQD',
            1 => 'Iraqi Dinar',
        ],
        'IRR' => [
            0 => 'IRR',
            1 => 'Iranian Rial',
        ],
        'ISK' => [
            0 => 'ISK',
            1 => 'Icelandic Króna',
        ],
        'JOD' => [
            0 => 'JOD',
            1 => 'Jordanian Dinar',
        ],
        'JPY' => [
            0 => 'JPY',
            1 => 'Japanese Yen',
        ],
        'KES' => [
            0 => 'KES',
            1 => 'Kenyan Shilling',
        ],
        'KGS' => [
            0 => 'KGS',
            1 => 'Kyrgystani Som',
        ],
        'KHR' => [
            0 => 'KHR',
            1 => 'Cambodian Riel',
        ],
        'KMF' => [
            0 => 'KMF',
            1 => 'Comorian Franc',
        ],
        'KPW' => [
            0 => 'KPW',
            1 => 'North Korean Won',
        ],
        'KRW' => [
            0 => 'KRW',
            1 => 'South Korean Won',
        ],
        'KWD' => [
            0 => 'KWD',
            1 => 'Kuwaiti Dinar',
        ],
        'KZT' => [
            0 => 'KZT',
            1 => 'Kazakhstani Tenge',
        ],
        'LAK' => [
            0 => 'LAK',
            1 => 'Laotian Kip',
        ],
        'LBP' => [
            0 => 'LBP',
            1 => 'Lebanese Pound',
        ],
        'LKR' => [
            0 => 'LKR',
            1 => 'Sri Lankan Rupee',
        ],
        'LRD' => [
            0 => 'LRD',
            1 => 'Liberian Dollar',
        ],
        'LSL' => [
            0 => 'LSL',
            1 => 'Lesotho Loti',
        ],
        'LYD' => [
            0 => 'LYD',
            1 => 'Libyan Dinar',
        ],
        'MAD' => [
            0 => 'MAD',
            1 => 'Moroccan Dirham',
        ],
        'MDL' => [
            0 => 'MDL',
            1 => 'Moldovan Leu',
        ],
        'MGA' => [
            0 => 'MGA',
            1 => 'Malagasy Ariary',
        ],
        'MKD' => [
            0 => 'MKD',
            1 => 'Macedonian Denar',
        ],
        'MMK' => [
            0 => 'MMK',
            1 => 'Myanmar Kyat',
        ],
        'MNT' => [
            0 => 'MNT',
            1 => 'Mongolian Tugrik',
        ],
        'MOP' => [
            0 => 'MOP',
            1 => 'Macanese Pataca',
        ],
        'MRO' => [
            0 => 'MRO',
            1 => 'Mauritanian Ouguiya (1973–2017)',
        ],
        'MUR' => [
            0 => 'MUR',
            1 => 'Mauritian Rupee',
        ],
        'MVR' => [
            0 => 'MVR',
            1 => 'Maldivian Rufiyaa',
        ],
        'MWK' => [
            0 => 'MWK',
            1 => 'Malawian Kwacha',
        ],
        'MXN' => [
            0 => 'MXN',
            1 => 'Mexican Peso',
        ],
        'MYR' => [
            0 => 'MYR',
            1 => 'Malaysian Ringgit',
        ],
        'MZN' => [
            0 => 'MZN',
            1 => 'Mozambican Metical',
        ],
        'NAD' => [
            0 => 'NAD',
            1 => 'Namibian Dollar',
        ],
        'NGN' => [
            0 => 'NGN',
            1 => 'Nigerian Naira',
        ],
        'NOK' => [
            0 => 'NOK',
            1 => 'Norwegian Krone',
        ],
        'NPR' => [
            0 => 'NPR',
            1 => 'Nepalese Rupee',
        ],
        'NZD' => [
            0 => 'NZD',
            1 => 'New Zealand Dollar',
        ],
        'OMR' => [
            0 => 'OMR',
            1 => 'Omani Rial',
        ],
        'PEN' => [
            0 => 'PEN',
            1 => 'Peruvian Sol',
        ],
        'PGK' => [
            0 => 'PGK',
            1 => 'Papua New Guinean Kina',
        ],
        'PHP' => [
            0 => 'PHP',
            1 => 'Philippine Peso',
        ],
        'PLN' => [
            0 => 'PLN',
            1 => 'Polish Zloty',
        ],
        'PYG' => [
            0 => 'PYG',
            1 => 'Paraguayan Guarani',
        ],
        'QAR' => [
            0 => 'QAR',
            1 => 'Qatari Riyal',
        ],
        'RON' => [
            0 => 'RON',
            1 => 'Romanian Leu',
        ],
        'RSD' => [
            0 => 'RSD',
            1 => 'Serbian Dinar',
        ],
        'RUB' => [
            0 => 'RUB',
            1 => 'Russian Rouble',
        ],
        'RWF' => [
            0 => 'RWF',
            1 => 'Rwandan Franc',
        ],
        'SAR' => [
            0 => 'SAR',
            1 => 'Saudi Riyal',
        ],
        'SBD' => [
            0 => 'SBD',
            1 => 'Solomon Islands Dollar',
        ],
        'SCR' => [
            0 => 'Rs',
            1 => 'Seychellois Rupee',
        ],
        'SDG' => [
            0 => 'SDG',
            1 => 'Sudanese Pound',
        ],
        'SEK' => [
            0 => 'SEK',
            1 => 'Swedish Krona',
        ],
        'SGD' => [
            0 => 'SGD',
            1 => 'Singapore Dollar',
        ],
        'SHP' => [
            0 => 'SHP',
            1 => 'St Helena Pound',
        ],
        'SOS' => [
            0 => 'SOS',
            1 => 'Somali Shilling',
        ],
        'SRD' => [
            0 => 'SRD',
            1 => 'Suriname Dollar',
        ],
        'SSP' => [
            0 => 'SSP',
            1 => 'South Sudanese Pound',
        ],
        'SYP' => [
            0 => 'SYP',
            1 => 'Syrian Pound',
        ],
        'SZL' => [
            0 => 'SZL',
            1 => 'Swazi Lilangeni',
        ],
        'TJS' => [
            0 => 'TJS',
            1 => 'Tajikistani Somoni',
        ],
        'TMT' => [
            0 => 'TMT',
            1 => 'Turkmenistani Manat',
        ],
        'TND' => [
            0 => 'TND',
            1 => 'Tunisian Dinar',
        ],
        'TOP' => [
            0 => 'TOP',
            1 => 'Tongan Paʻanga',
        ],
        'TRY' => [
            0 => 'TRY',
            1 => 'Turkish Lira',
        ],
        'TWD' => [
            0 => 'TWD',
            1 => 'New Taiwan Dollar',
        ],
        'TZS' => [
            0 => 'TZS',
            1 => 'Tanzanian Shilling',
        ],
        'UAH' => [
            0 => 'UAH',
            1 => 'Ukrainian Hryvnia',
        ],
        'UGX' => [
            0 => 'UGX',
            1 => 'Ugandan Shilling',
        ],
        'USD' => [
            0 => 'USD',
            1 => 'US Dollar',
        ],
        'UYU' => [
            0 => 'UYU',
            1 => 'Peso Uruguayo',
        ],
        'UZS' => [
            0 => 'UZS',
            1 => 'Uzbekistani Som',
        ],
        'VEF' => [
            0 => 'VEF',
            1 => 'Venezuelan Bolívar (2008–2018)',
        ],
        'VES' => [
            0 => 'VES',
            1 => 'Venezuelan bolívar',
        ],
        'VND' => [
            0 => 'VND',
            1 => 'Vietnamese Dong',
        ],
        'VUV' => [
            0 => 'VUV',
            1 => 'Vanuatu Vatu',
        ],
        'WST' => [
            0 => 'WST',
            1 => 'Samoan Tala',
        ],
        'XAF' => [
            0 => 'XAF',
            1 => 'Central African CFA Franc',
        ],
        'XCD' => [
            0 => 'XCD',
            1 => 'East Caribbean Dollar',
        ],
        'XOF' => [
            0 => 'XOF',
            1 => 'West African CFA Franc',
        ],
        'XPF' => [
            0 => 'CFP',
            1 => 'CFP Franc',
        ],
        'YER' => [
            0 => 'YER',
            1 => 'Yemeni Rial',
        ],
        'ZAR' => [
            0 => 'ZAR',
            1 => 'South African Rand',
        ],
        'ZMW' => [
            0 => 'ZMW',
            1 => 'Zambian Kwacha',
        ],
    ],
];
